mysql.conversion.output

Package mysql :: Package conversion :: Module output |
[hide private]
[frames] | no frames]

# Module output

source code

Output Conversion converts values from MySQL (which are always strings) to Python data types.

The base class Output_Conversion defines the API for converting values.

The class Basic_Conversion is the default conversion used if you do not specify a conversion instance.

The class No_Conversion may be used if you do not want any values converted.

NULL values are always converted to None, and are not passed into the `convert` method.

Classes | [hide private]
`` | Output_Conversion Base class for the output conversion API.
`` | No_Conversion Does no conversion, all values are returned as strings.
`` | Basic_Conversion The default conversion class used if none is specified.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.4 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.4 $'